import { graphql } from "@/gql";
import { EventFragment } from "@/gql/graphql";
import { getClient } from "@/app/client";
import { FeaturedEvents } from "@/components/events/FeaturedEvents";
import { Body } from "@/components/general/Body";
import Image from "next/image";
import { PersonList } from "@/components/people/PersonList";
import { NewsList } from "@/components/news/NewsList";
import { PersonSection } from "@/components/people/PersonSection";
import { UpcomingEvents } from "@/components/events/UpcomingEvents";

export default async function Home() {
  const homeQuery = graphql(`
    query home {
      events: pages(contentType: "events.EventPage") {
        ...Event
      }
    }
  `);
  const { data, error } = await getClient().query(homeQuery, {});
  const events = (data?.events ?? []) as EventFragment[];

  return (
    <main className="site-main" id="main">
      <div>
        <FeaturedEvents events={events} />
        <UpcomingEvents events={events} />
        <NewsList heading="Siste nytt" limit={3} featured />
        <blockquote>«Hvor Glæden hersker, er alltid Fest»</blockquote>
      </div>
    </main>
  );
}
